@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2003 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2005 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,8 +28,6 @@ typedef enum
 	STOCK_PIXMAP_ADDRESS,
 	STOCK_PIXMAP_BOOK,
 	STOCK_PIXMAP_CATEGORY,
-	STOCK_PIXMAP_CHECKBOX_OFF,
-	STOCK_PIXMAP_CHECKBOX_ON,
 	STOCK_PIXMAP_CLIP,
 	STOCK_PIXMAP_COMPLETE,
 	STOCK_PIXMAP_CONTINUE,
@@ -40,18 +38,23 @@ typedef enum
 	STOCK_PIXMAP_ERROR,
 	STOCK_PIXMAP_FORWARDED,
 	STOCK_PIXMAP_GROUP,
-	STOCK_PIXMAP_INBOX,
 	STOCK_PIXMAP_INTERFACE,
 	STOCK_PIXMAP_JPILOT,
 	STOCK_PIXMAP_LDAP,
 	STOCK_PIXMAP_LINEWRAP,
 	STOCK_PIXMAP_MARK,
 	STOCK_PIXMAP_NEW,
-	STOCK_PIXMAP_OUTBOX,
 	STOCK_PIXMAP_REPLIED,
-	STOCK_PIXMAP_CLOSE,
-	STOCK_PIXMAP_DOWN_ARROW,
-	STOCK_PIXMAP_EXEC,
+	STOCK_PIXMAP_UNREAD,
+	STOCK_PIXMAP_VCARD,
+	STOCK_PIXMAP_ONLINE,
+	STOCK_PIXMAP_OFFLINE,
+	STOCK_PIXMAP_MAIL_SMALL,
+
+	STOCK_PIXMAP_INBOX,
+	STOCK_PIXMAP_OUTBOX,
+	STOCK_PIXMAP_DRAFT,
+	STOCK_PIXMAP_TRASH,
 	STOCK_PIXMAP_MAIL,
 	STOCK_PIXMAP_MAIL_ATTACH,
 	STOCK_PIXMAP_MAIL_COMPOSE,
@@ -62,25 +65,31 @@ typedef enum
 	STOCK_PIXMAP_MAIL_REPLY_TO_ALL,
 	STOCK_PIXMAP_MAIL_SEND,
 	STOCK_PIXMAP_MAIL_SEND_QUEUE,
-	STOCK_PIXMAP_PASTE,
-	STOCK_PIXMAP_PREFERENCES,
-	STOCK_PIXMAP_PROPERTIES,
-	STOCK_PIXMAP_SYLPHEED_LOGO,
+	STOCK_PIXMAP_INSERT_FILE,
 	STOCK_PIXMAP_ADDRESS_BOOK,
-	STOCK_PIXMAP_TRASH,
-	STOCK_PIXMAP_UNREAD,
-	STOCK_PIXMAP_VCARD,
-	STOCK_PIXMAP_ONLINE,
-	STOCK_PIXMAP_OFFLINE,
+	STOCK_PIXMAP_DELETE,
+	STOCK_PIXMAP_SPAM,
+	STOCK_PIXMAP_SIGN,
+	STOCK_PIXMAP_SYLPHEED,
+	STOCK_PIXMAP_SYLPHEED_LOGO,
 
 	N_STOCK_PIXMAPS
 } StockPixmap;
 
-GtkWidget *stock_pixmap_widget	(GtkWidget	 *window,
+GtkWidget *stock_pixbuf_widget	(GtkWidget	 *window,
 				 StockPixmap	  icon);
+
+GtkWidget *stock_pixbuf_widget_scale	(GtkWidget	*window,
+					 StockPixmap	 icon,
+					 gint		 width,
+					 gint		 height);
+
 gint stock_pixmap_gdk		(GtkWidget	 *window,
 				 StockPixmap	  icon,
 				 GdkPixmap	**pixmap,
 				 GdkBitmap	**mask);
+gint stock_pixbuf_gdk		(GtkWidget	 *window,
+				 StockPixmap	  icon,
+				 GdkPixbuf	**pixbuf);
 
 #endif /* __STOCK_PIXMAP_H__ */
